pub mod lib;
pub mod vistas;

use axum::{
    routing::{get, post},
    Router,
};
use std::net::SocketAddr;
use crate::lib::env_listen_port;

use crate::vistas::{download::get_file, root::basic, upload::upload};

#[tokio::main]
async fn main() {
    // initialize tracing
    tracing_subscriber::fmt::init();

    // build our application with a route
    let app = Router::new()
        .route("/", get(basic))
        .route("/", post(upload))
        .route("/f/:hash", get(get_file));

    // run our app with hyper
    // `axum::Server` is a re-export of `hyper::Server`
    let addr = SocketAddr::from(([127, 0, 0, 1], env_listen_port()));
    tracing::debug!("listening on {}", addr);
    axum::Server::bind(&addr)
        .serve(app.into_make_service())
        .await
        .unwrap();
}
