use axum::{
    body::StreamBody,
    http::{header, StatusCode},
    response::IntoResponse,
};
use tokio::fs::read_dir;
use tokio_util::io::ReaderStream;
use crate::lib::env_uploads_dir;

pub async fn get_file(axum::extract::Path(hash): axum::extract::Path<String>) -> impl IntoResponse {
    // find file from hash
    let (fpath, fname) = match find_file(hash).await {
        Ok(file) => file,
        Err(err) => return Err((StatusCode::NOT_FOUND, format!("File not found: {}", err))),
    };

    // `File` implements `AsyncRead`
    let file = match tokio::fs::File::open(fpath).await {
        Ok(file) => file,
        Err(err) => return Err((StatusCode::NOT_FOUND, format!("File not found: {}", err))),
    };
    // convert the `AsyncRead` into a `Stream`
    let stream = ReaderStream::new(file);
    // convert the `Stream` into an `axum::body::HttpBody`
    let body = StreamBody::new(stream);

    let headers = [
        // (header::CONTENT_TYPE, "text/toml; charset=utf-8"),
        (
            header::CONTENT_DISPOSITION,
            format!("attachment; filename=\"{}\"", fname),
        ),
    ];

    Ok((headers, body))
}

// uploads/O/OfsdaDF/proba.txt
async fn find_file(hash: String) -> Result<(String, String), tokio::io::Error> {
    let mut file_path = String::from("");
    let mut file_name = String::from("");
    let pai = &hash[0..1]; //primeiro char
    let path = format!("{}/{}/{}", env_uploads_dir(), pai, hash);

    let mut dir = read_dir(path).await?;
    while let Some(child) = dir.next_entry().await? {
        file_path = child.path().display().to_string();
        file_name = child.file_name().into_string().unwrap();
    }
    Ok((file_path, file_name))
}
